@@ -1,3 +1,4 @@
+use std::mem::ManuallyDrop;
 use std::ops::Deref;
 
 /// Utility struct for creating a `BufferView` that auto unmaps when dropped.
@@ -5,7 +6,7 @@ pub struct ScopedBufferView<'a> {
     /// The inner buffer view.
     /// This is `Option` because it needs to be dropped before the buffer can be
     /// unmapped, however it will not be `None` until the scope is dropped.
-    buffer_view: Option<wgpu::BufferView<'a>>,
+    buffer_view: ManuallyDrop<wgpu::BufferView<'a>>,
     /// Reference to the Buffer so we can unmap it when the view is dropped.
     buffer: &'a wgpu::Buffer,
 }
@@ -14,8 +15,8 @@ impl<'a> ScopedBufferView<'a> {
         buffer: &'a wgpu::Buffer,
         buffer_view: wgpu::BufferView<'a>,
     ) -> ScopedBufferView<'a> {
-        // Wrap in Option
-        let buffer_view = Some(buffer_view);
+        // Wrap in ManuallyDrop
+        let buffer_view = ManuallyDrop::new(buffer_view);
         ScopedBufferView {
             buffer_view,
             buffer,
@@ -25,13 +26,12 @@ impl<'a> ScopedBufferView<'a> {
 impl<'a> Deref for ScopedBufferView<'a> {
     type Target = wgpu::BufferView<'a>;
     fn deref(&self) -> &Self::Target {
-        // We can always unwrap this
-        self.buffer_view.as_ref().unwrap()
+        &self.buffer_view
     }
 }
 impl Drop for ScopedBufferView<'_> {
     fn drop(&mut self) {
-        self.buffer_view = None;
+        unsafe { ManuallyDrop::drop(&mut self.buffer_view) }
         self.buffer.unmap();
     }
 }
