@@ -1,17 +1,19 @@
-use crate::{GpuHandle, Viewport};
+use crate::{Gpu, Viewport};
 use winit::window::Window;
 
 pub struct ViewportBuilder {
-    pub gpu: GpuHandle,
+    pub gpu: Gpu,
     pub window: Window,
     pub format: Option<wgpu::TextureFormat>,
+    pub usages: wgpu::TextureUsages,
 }
 impl<'a> ViewportBuilder {
-    pub fn new(gpu: GpuHandle, window: Window) -> Self {
+    pub fn new(gpu: Gpu, window: Window) -> Self {
         Self {
             gpu,
             window,
             format: None,
+            usages: wgpu::TextureUsages::empty(),
         }
     }
 
@@ -20,6 +22,11 @@ impl<'a> ViewportBuilder {
         self
     }
 
+    pub fn with_usages(mut self, usages: wgpu::TextureUsages) -> Self {
+        self.usages = usages;
+        self
+    }
+
     /// Build the Viewport.
     /// Note this builder is consumed to pass the GpuHandle to the built Viewport.
     pub fn create(self) -> Viewport {
